@@ -4,16 +4,15 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -24,7 +23,7 @@
 
 #include "includes/httraqt.h"
 #include "includes/AboutDialog.h"
-#include "../icons/httraqt_icon.h"
+// #include "../icons/httraqt_icon.h"
 #include "../version.h"
 
 
@@ -39,7 +38,7 @@ AboutDialog::AboutDialog(QWidget *parent, Qt::WindowFlags fl)
 
     translateDialog();
     connect(pushButton, SIGNAL(clicked()), this, SLOT(reject()));
-    label_2->setPixmap(QPixmap(httraq_xpm));
+    label_2->setPixmap(*(this->parent->mainpix));
 
     adjustSize();
 }
@@ -64,11 +63,10 @@ void AboutDialog::translateDialog()
 
     label->setText(outStr);
 
-    QString l = QString().sprintf(" <a href=\"%s\">PayPal link</a>", DONATE_STR);
     QString t = "<b>" + translate(_HOW_THANK) + "</b><br><br>"
                 "- " + translate(_SHARE_LINK) + "<br>"
                 "- " + translate(_REPORT_BUG) + "<br>"
-                "- " + translate(_MAKE_DONATE) + l;
+                "- " + translate(_MAKE_DONATE) + ". " + translate(_MAKE_TRANSLATION);
 
     label_3->setText(t);
     label_3->setTextFormat(Qt::RichText);
