@@ -4,16 +4,15 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -27,7 +26,9 @@ ConfirmTab::ConfirmTab(QWidget *parent, Qt::WindowFlags fl) : QWidget(parent, fl
     setupUi(this);
 
     this->parent = static_cast<HTTraQt*>(parent);
-    
+
+    lineEditCounter->setText("5");
+
     connect(radioSave, SIGNAL(toggled(bool)), this, SLOT(onRadio(bool)));
     connect(radioStart, SIGNAL(toggled(bool)), this, SLOT(onRadio(bool)));
 
@@ -53,19 +54,20 @@ ConfirmTab::ConfirmTab(QWidget *parent, Qt::WindowFlags fl) : QWidget(parent, fl
 void ConfirmTab::onRadio(bool b)
 {
     QRadioButton* bu = (QRadioButton*) sender();
-    
+
     disconnect(radioSave, SIGNAL(toggled(bool)), this, SLOT(onRadio(bool)));
     disconnect(radioStart, SIGNAL(toggled(bool)), this, SLOT(onRadio(bool)));
-    
-    if (bu == radioSave){
+
+    if (bu == radioSave) {
         bool ch = radioSave->isChecked();
         radioStart->setChecked(!ch);
     }
-    if (bu == radioStart){
+
+    if (bu == radioStart) {
         bool ch = radioStart->isChecked();
         radioSave->setChecked(!ch);
     }
-    
+
     connect(radioSave, SIGNAL(toggled(bool)), this, SLOT(onRadio(bool)));
     connect(radioStart, SIGNAL(toggled(bool)), this, SLOT(onRadio(bool)));
 }
@@ -84,6 +86,7 @@ void ConfirmTab::translateTab()
     radioSave->setText(translate(_SAV_SETTINGS));
     group02->setTitle(translate(_ON_HOLD));
     groupPCoff->setTitle(translate(_PC_OFF));
+    labelCounter->setText(translate(_SHUTDOWN_COUNTER));
 }
 
 
