@@ -4,16 +4,15 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -102,7 +101,7 @@ void OptionsTab::onCaptureUrl()
 
         textEdit->setText(st);
     } else {
-        MessageBox::exec(translate(_ERR), translate(_WRONGURLS), QMessageBox::Warning);
+        MessageBox::exec(this, translate(_ERR), translate(_WRONGURLS), QMessageBox::Warning);
     }
 }
 
@@ -187,7 +186,7 @@ void OptionsTab::onAddURL()
 
         textEdit->setText(st);
     } else {
-        MessageBox::exec(translate(_ERR), translate(_WRONGURLS), QMessageBox::Warning);
+        MessageBox::exec(this, translate(_ERR), translate(_WRONGURLS), QMessageBox::Warning);
     }
 
     delete dUrl;
@@ -210,7 +209,7 @@ void OptionsTab::onURLList()
     //     fd = new QFileDialog(this, translate(_OPENFILE), parent->currentWorkDir, str);
     //     fd->setFont(parent->systemFont);
     //     fd->exec();
-    QString name = QFileDialog::getOpenFileName(NULL, translate(_OPENFILE), parent->currentWorkDir, str);
+    QString name = QFileDialog::getOpenFileName(this, translate(_OPENFILE), parent->currentWorkDir, str);
 
     if (name == "" || name == "/" || name == "\\") {
         return;
@@ -246,7 +245,7 @@ void OptionsTab::onURLList()
     if (st.length() > 0) {
         textEdit->setText(st);
     } else {
-        MessageBox::exec(translate(_ERR), translate(_WRONGURLS), QMessageBox::Warning);
+        MessageBox::exec(this, translate(_ERR), translate(_WRONGURLS), QMessageBox::Warning);
     }
 }
 
@@ -256,6 +255,8 @@ void OptionsTab::onSetOptions()
     OptionsDialog *oDia = new OptionsDialog(parent);
     //     oDia->setFont(parent->systemFont);
     oDia->exec();
+
+    delete oDia;
 }
 
 
@@ -281,7 +282,7 @@ bool OptionsTab::testIt()
     if (found == true) {
         parent->SetProfile("CurrentUrl", listOfUrls);
     } else {
-        MessageBox::exec(translate(_ERR), translate(_WRONGURLS), QMessageBox::Warning);
+        MessageBox::exec(this, translate(_ERR), translate(_WRONGURLS), QMessageBox::Warning);
     }
 
     QString urlFile = label1286->text();
