@@ -4,16 +4,15 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -50,6 +49,10 @@ extern int hts_is_exiting(httrackp *opt);
 #endif
 
 
+#define DESCR_COLUMN    0
+#define FILENAME_COLUMN 1
+#define SIZE_COLUMN     2
+#define CANCEL_COLUMN   3
 
 #include "includes/httraqt.h"
 #include "includes/ProgressTab.h"
@@ -63,23 +66,23 @@ ProgressTab::ProgressTab(QWidget *parent, Qt::WindowFlags fl)
     this->parent = static_cast<HTTraQt*>(parent);
     this->parent->global_opt = NULL;
 
-    tableWidget->setColumnCount(4);
-    //     tableWidget->setColumnHidden(3 , true);
-    tableWidget->setRowCount(NStatsBuffer);
+    progressSheet->setColumnCount(4);
+    //     progressSheet->setColumnHidden(3 , true);
+    progressSheet->setRowCount(NStatsBuffer);
 
     QPalette* palette1 = new QPalette();
     palette1->setColor(QPalette::ButtonText, Qt::red);
 
     // qDebug() << "progresstab" << NStatsBuffer;
     for (int i = 0; i < NStatsBuffer; i++) {
-        tableWidget->setCellWidget(i, 0, new QLabel());
+        progressSheet->setCellWidget(i, 0, new QLabel());
 
         QProgressBar* pb = new QProgressBar();
         pb->setRange(0, 1000);
-        tableWidget->setRowHeight(i, 20);
-        tableWidget->setCellWidget(i, 1, pb);
+        progressSheet->setRowHeight(i, 20);
+        progressSheet->setCellWidget(i, 1, pb);
 
-        tableWidget->setCellWidget(i, 2, new QLabel());
+        progressSheet->setCellWidget(i, 2, new QLabel());
         // "<font color=darkred><b>X</b></font>"
 
         QPushButton *nb;
@@ -89,14 +92,14 @@ ProgressTab::ProgressTab(QWidget *parent, Qt::WindowFlags fl)
         nb->setHidden(true);
         cancelButtons << nb;
 
-        tableWidget->setCellWidget( i, 3, nb);// for cancelButtons
-        //         tableWidget->cellWidget(i, 3)->setHidden(true);
+        progressSheet->setCellWidget( i, 3, nb);// for cancelButtons
+        //         progressSheet->cellWidget(i, 3)->setHidden(true);
 
         connect(nb, SIGNAL(pressed()), this, SLOT(cancelDwnload()));
     }
 
     //     for (int i = 0; i < NStatsBuffer; i++) {
-    //         tableWidget->setRowHidden(i, (i >= this->parent->maxProgressRows));
+    //         progressSheet->setRowHidden(i, (i >= this->parent->maxProgressRows));
     //     }
 }
 
@@ -104,10 +107,10 @@ ProgressTab::ProgressTab(QWidget *parent, Qt::WindowFlags fl)
 void ProgressTab::resizeEvent(QResizeEvent *event)
 {
     int tableWidth = width();
-    tableWidget->setColumnWidth(0, tableWidth * 0.12);
-    tableWidget->setColumnWidth(1, tableWidth * 0.50);
-    tableWidget->setColumnWidth(2, tableWidth * 0.12); // for size
-    tableWidget->setColumnWidth(3, tableWidth * 0.10); // for "cancel" button
+    progressSheet->setColumnWidth(0, tableWidth * 0.12);
+    progressSheet->setColumnWidth(1, tableWidth * 0.50);
+    progressSheet->setColumnWidth(2, tableWidth * 0.12); // for size
+    progressSheet->setColumnWidth(3, tableWidth * 0.10); // for "cancel" button
 }
 
 
@@ -135,10 +138,10 @@ void ProgressTab::translateTab()
                 << translate(_SIZE)
                 << "";
 
-    tableWidget->setHorizontalHeaderLabels(horzHeaders);
+    progressSheet->setHorizontalHeaderLabels(horzHeaders);
 
     //     for (int i = 0; i < NStatsBuffer; i++) {
-    //         tableWidget->setRowHidden(i, (i >= parent->maxProgressRows));
+    //         progressSheet->setRowHidden(i, (i >= parent->maxProgressRows));
     //     }
 }
 
@@ -265,7 +268,7 @@ void ProgressTab::inProcessRefresh()
             i1->setText(st);          // time
         }
 
-        float mbytes = parent->SInfo.stat_bytes / 1e6;
+        float mbytes = parent->SInfo.stat_bytes / (1024.0 * 1024.0);
 
         if (mbytes > 1.0 && mbytes < 1024.0) {
             i0->setText(QString().sprintf("%.2f MB", mbytes));       // bytes
@@ -277,7 +280,7 @@ void ProgressTab::inProcessRefresh()
 
         i2->setText(lnk);    // scanned
 
-        if (parent->SInfo.stat_nsocket > 0 && parent->SInfo.stat_nsocket < 32) {
+        if (parent->SInfo.stat_nsocket > 0 /*&& parent->SInfo.stat_nsocket < 32*/) {
             QString st = QString::number(parent->SInfo.stat_nsocket);
             i3->setText(st);          // socks
         } else {
@@ -286,7 +289,7 @@ void ProgressTab::inProcessRefresh()
 
         QString st;
 
-        if (parent->SInfo.rate < 0 || parent->SInfo.rate > 1e6) {
+        if (parent->SInfo.rate < 0 || parent->SInfo.rate > (1024.0 * 1024.0)) {
             parent->SInfo.rate = 0;
         }
 
@@ -314,8 +317,8 @@ void ProgressTab::inProcessRefresh()
         i7->setText(tempo);
 
         //         for (int j = 0; j < NStatsBuffer; j++) {
-        //             tableWidget->setRowHidden(j, (j >= parent->maxProgressRows));
-        //             //         tableWidget->cellWidget(i, 3)->setHidden(false);
+        //             progressSheet->setRowHidden(j, (j >= parent->maxProgressRows));
+        //             //         progressSheet->cellWidget(i, CANCEL_COLUMN)->setHidden(false);
         //         }
 
         /*if (!parsing)*/
@@ -326,6 +329,24 @@ void ProgressTab::inProcessRefresh()
                         TStamp d = ((TStamp) parent->StatsBuffer[i].size * 1000);
                         d = d / ((TStamp) parent->StatsBuffer[i].sizeTotal);
                         parent->StatsBuffer[i].offset = (int) d;
+
+                        QLabel *tsize = (QLabel*) progressSheet->cellWidget(i, SIZE_COLUMN);
+                        qint64 sz = parent->StatsBuffer[i].sizeTotal;
+                        QString s;
+
+                        if (sz < 1e3) { // bytes
+                            s.sprintf("%4.1f B", (float)sz);
+                        } else if ((sz >= 1000) && (sz < 1e6)) { // kBytes
+                            s.sprintf("%4.1f kB", (float)(sz / 1024.0));
+                        } else if ((sz >= 1e6) && (sz < 1e9)) { // kBytes
+                            s.sprintf("%4.1f MB", (float)(sz / (1024.0 * 1024.0)));
+                        } else { // mbytes
+                            s.sprintf("%4.1f GB", (float)(sz / (1024.0 * 1024.0 * 1024.0)));
+                        }
+
+                        if (s.length() > 0) {
+                            tsize->setText(s);
+                        }
                     } else {
                         parent->StatsBuffer[i].offset = 0;
                     }
@@ -334,19 +355,19 @@ void ProgressTab::inProcessRefresh()
 
             if (!parsing) {
                 QProgressBar *p;
-                p = (QProgressBar *) tableWidget->cellWidget(0, 1);
+                p = (QProgressBar *) progressSheet->cellWidget(0, FILENAME_COLUMN);
                 p->setRange(0, 1000);
 
-                p = (QProgressBar *) tableWidget->cellWidget(0, 1);
+                p = (QProgressBar *) progressSheet->cellWidget(0, FILENAME_COLUMN);
                 p->setValue(parent->StatsBuffer[0].offset);
             }
 
             for (int j = 1; j < NStatsBuffer; j++) {
                 QProgressBar *p;
-                p = (QProgressBar *) tableWidget->cellWidget(j, 1);
+                p = (QProgressBar *) progressSheet->cellWidget(j, FILENAME_COLUMN);
                 p->setRange(0, 1000);
 
-                p = (QProgressBar *) tableWidget->cellWidget(j, 1);
+                p = (QProgressBar *) progressSheet->cellWidget(j, FILENAME_COLUMN);
                 p->setValue(parent->StatsBuffer[j].offset);
             }
 
@@ -360,26 +381,28 @@ void ProgressTab::inProcessRefresh()
 
                 for( ; i < NStatsBuffer; i++) {
                     QString st;
-                    QLabel *ti = (QLabel*) tableWidget->cellWidget(i, 0);
+                    QLabel *ti = (QLabel*) progressSheet->cellWidget(i, DESCR_COLUMN);
                     st = parent->StatsBuffer[i].strStatus;
                     st.replace("&", "&&");
 
                     if (st.length() == 0) {
-                        tableWidget->cellWidget(i, 3)->setHidden(true);
-                        if (tableWidget->isRowHidden(i) == false) {
-                            tableWidget->setRowHidden(i, true);
+                        progressSheet->cellWidget(i, CANCEL_COLUMN)->setHidden(true);
+
+                        if (progressSheet->isRowHidden(i) == false) {
+                            progressSheet->setRowHidden(i, true);
                         }
                     } else {
-                        tableWidget->cellWidget(i, 3)->setHidden(false);
-                        if (tableWidget->isRowHidden(i) == true) {
-                            tableWidget->setRowHidden(i, false);
+                        progressSheet->cellWidget(i, CANCEL_COLUMN)->setHidden(false);
+
+                        if (progressSheet->isRowHidden(i) == true) {
+                            progressSheet->setRowHidden(i, false);
                         }
 
                         ti->setText(st);
 
                         QProgressBar *p;
-                        p = (QProgressBar *) tableWidget->cellWidget(i, 1);
-                        //ti = (QLabel*) tableWidget->cellWidget(i, 1);
+                        p = (QProgressBar *) progressSheet->cellWidget(i, FILENAME_COLUMN);
+                        //ti = (QLabel*) progressSheet->cellWidget(i,FILENAME_COLUMN);
                         st = parent->StatsBuffer[i].name;
                         st.replace("&", "&&");
                         p->setFormat( st);
@@ -388,26 +411,26 @@ void ProgressTab::inProcessRefresh()
                         st.replace("&", "&&");
                         p->setToolTip(st);
 
-                        if (!parsing) {
-//                             if (parent->StatsBuffer[i].strStatus.length() > 0){
-//                                 tableWidget->cellWidget(i, 3)->setHidden(false);
-//                             }
-//                             else{
-//                                 tableWidget->cellWidget(i, 3)->setHidden(true);
-//                             }
+
+//                         if (!parsing) {
+                            //                             if (parent->StatsBuffer[i].strStatus.length() > 0){
+                            //                                 progressSheet->cellWidget(i, CANCEL_COLUMN)->setHidden(false);
+                            //                             }
+                            //                             else{
+                            //                                 progressSheet->cellWidget(i, CANCEL_COLUMN)->setHidden(true);
+                            //                             }
                             if ((parent->StatsBuffer[i].strStatus.length() == 0) != (parent->StatsBuffer[i].actived)) {
                                 parent->StatsBuffer[i].actived = !parent->StatsBuffer[i].actived;
 
-//                                 if (!parent->StatsBuffer[i].actived) {
-//                                     tableWidget->cellWidget(i, 3)->setHidden(true);
-//                                 } else {
-//                                     tableWidget->cellWidget(i, 3)->setHidden(false);
-//                                 }
-
-                                //                         inprogress->element[3][i]->RedrawWindow();
+                                if (!parent->StatsBuffer[i].actived) {
+                                    progressSheet->cellWidget(i, CANCEL_COLUMN)->setHidden(true);
+                                } else {
+                                    progressSheet->cellWidget(i, CANCEL_COLUMN)->setHidden(false);
+                                }
                             }
-                        }/* else {
-                            tableWidget->cellWidget(i, 3)->setHidden(true);
+                  /*      } else {
+
+                            progressSheet->cellWidget(i, CANCEL_COLUMN)->setHidden(true);
                         }*/
                     }
                 }
@@ -419,20 +442,16 @@ void ProgressTab::inProcessRefresh()
         if (parsing) {  // parsing
             //
             QProgressBar *p;
-            p = (QProgressBar *) tableWidget->cellWidget(0, 1);
+            p = (QProgressBar *) progressSheet->cellWidget(0, FILENAME_COLUMN);
             p->setRange(0, 100);
             p->setValue(parsing);
-            //             inprogress->m_sl0.SetRange(0, 100);
-            //             inprogress->m_sl0.SetPos(parsing);
-            QLabel *ti = (QLabel*) tableWidget->cellWidget(0, 0);
+
+            QLabel *ti = (QLabel*) progressSheet->cellWidget(0, DESCR_COLUMN);
             ti->setText(translate(_SCANNING));
-            //             SetWindowTextCP(inprogress->element[0][0], LANG(LANG_F14 /*"scanning","parcours"*/));
-            p = (QProgressBar *) tableWidget->cellWidget(0, 1);
+
+            p = (QProgressBar *) progressSheet->cellWidget(0, FILENAME_COLUMN);
             p->setFormat(parent->StatsBuffer[0].name);
 
-            //             tableWidget->cellWidget(0, 3)->setHidden(true);
-            //             SetWindowTextCP(inprogress->element[4][0], "");
-            //inprogress->element[0][1]->SetWindowTextCP(this, );
         }
     }
 
@@ -441,7 +460,7 @@ void ProgressTab::inProcessRefresh()
     QTableWidgetItem * ti;
 
     if ((parent->SInfo.stat_nsocket == -1)) {
-        ti = tableWidget->item(0, 0);
+        ti = progressSheet->item(0, DESCR_COLUMN);
 
         if (ti == NULL) {
             return;
@@ -463,8 +482,8 @@ void ProgressTab::inProcessRefresh()
         } else {
             QString byteb;
 
-            if (parent->SInfo.stat_bytes > 1e6) {
-                byteb = QString().sprintf("%.2f MB", parent->SInfo.stat_bytes / 1e6);     // bytes
+            if (parent->SInfo.stat_bytes > (1024.0 * 1024.0)) {
+                byteb = QString().sprintf("%.2f MB", parent->SInfo.stat_bytes / (1024.0 * 1024.0));     // bytes
             } else {
                 byteb = QString().sprintf("%d B", parent->SInfo.stat_bytes);
             }
