@@ -4,16 +4,15 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -42,7 +41,7 @@ void buttonPanel::onStop()
 {
     // progress tab
     if (parent->currentTab == 4) {
-        int ans = MessageBox::exec(translate(_STOPQ), translate(_STOPPROG), QMessageBox::Question);
+        int ans = MessageBox::exec(this, translate(_STOPQ), translate(_STOPPROG), QMessageBox::Question);
 
         if (ans == QMessageBox::Yes) {
             parent->onStopAll();
