@@ -4,22 +4,20 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
  ***************************************************************************/
 
-
 using namespace std;
 
 #include <QMainWindow>
@@ -27,6 +25,7 @@ using namespace std;
 #include <QStringList>
 #include <QString>
 #include <QDirModel>
+#include <QPixmap>
 #include <QMessageBox>
 #include <QSystemTrayIcon>
 #include <QTimer>
@@ -39,9 +38,10 @@ using namespace std;
 #define HTTRAQ_H
 
 
-#include "../../icons/main.h"
+// #include "../../icons/main.h"
 
 #include "translator.h"
+#include "options.h"
 
 #include "ui_mainForm.h"
 
@@ -59,6 +59,25 @@ using namespace std;
 
 #endif
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
+// #include "includes/htinterface.h"
+
+
+#include <httrack-library.h>
+#include <htsglobal.h>
+#include <htswrap.h>
+#include <htsopt.h>
+#include <htsdefines.h>
+
+
+#ifdef __cplusplus
+}
+#endif
+
 
 #define NStatsBuffer     14
 #define MAX_LEN_INPROGRESS 40
@@ -79,11 +98,6 @@ struct hInfo {
 };
 
 
-struct OptStruct {
-    short   type; // TEXT, INTEGER or FLOAT. if not number, default text
-    QVariant value;
-};
-
 
 typedef struct {
     QString name;
@@ -120,10 +134,10 @@ class MessageTimerBox: public QMessageBox
 };
 
 
-class MessageBox: public Translator
+class MessageBox: public cTranslator
 {
     public:
-        static int exec(const QString &title, const QString &text, int ticon);
+        static int exec(void* p, const QString &title, const QString &text, int ticon);
 };
 
 
@@ -141,7 +155,7 @@ class MyThread : public QThread
 };
 
 
-class HTTraQt: public QMainWindow, public Ui_MainWindow, public Translator
+class HTTraQt: public QMainWindow, public Ui::MainWindow, public cTranslator, public cOptions
 {
         Q_OBJECT
 
@@ -166,20 +180,13 @@ class HTTraQt: public QMainWindow, public Ui_MainWindow, public Translator
         void writeSettings(bool global);
         void writeGUISettings(void);
 
-        void SetProfile(const QString& variName, float val);
-        void SetProfile(const QString& variName, int val);
-        void SetProfile(const QString& variName, const QString &val);
-
-        void GetProfile(const QString& variName, int &val);
-        void GetProfile(const QString& variName, float &val);
-        void GetProfile(const QString& variName, QString &val);
         void clearStatsBuffer(void);
         void setFontForWidgets(void);
         void getOptions();
         void onEndMirror();
         bool checkContinue(bool msg);
         void afterChangepathlog();
-        void resetDefaultOptions();
+        //         void resetDefaultOptions();
         bool RemoveEmptyDir(QString path);
 
     public slots:
@@ -229,42 +236,40 @@ class HTTraQt: public QMainWindow, public Ui_MainWindow, public Translator
         void hibernate();
         void createTrayIcon();
         void renameOldToNew();
-        void convertTranslateFile();
+        void convertTranslateFiles();
         QString sizeToText(qint64 s);
         void gOptions(bool d);
         QString getLocaleString();
-        int  removeFolder(QDir & dir);
-        bool getStrOption(const QString optName, QString& ret);
-        bool getIntOption(const QString optName, int& ret);
+        int  removeFolder(QDir &dir);
+        bool getStrOption(const QString optName, QString &ret);
+        bool getIntOption(const QString optName, int &ret);
         void createActions();
         void createToolBars();
         void createStatusBar();
-        void loadOptions(QSettings *s);
-        void saveOptions(QSettings *s, bool gl);
 
-        void cmdArgumentsOptions();
-        void StripControls(QString& st);
+        //         void cmdArgumentsOptions();
+
         QString change(char* chaine, char c);
-        void profile_code(QString& from);
-        void profile_decode(QString& from);
         bool checkInstanceRuns();
 
         void contextMenuEvent(QContextMenuEvent *);
 
     public:
+        QPixmap *mainpix;
+        QPixmap *mainicon;
         QTimer *timerProgressUpdate;
         QTimer *timerDirRefresh;
         QWidget *widgets[6];
         //         QVector<options> prOptions;
-        QMap<QString, OptStruct> prOptions;
+        //         QMap<QString, OptStruct> prOptions;
         buttonPanel* buttonsWidget;
-        int maxProgressRows;
+
         int  m_todo;
 
     private:
         QSharedMemory *_singular;
         QString filename;
-        QString selectedLang;
+
         MyThread* mth;
         QString agumentsLine;
         QStringList lastDirs;
@@ -273,7 +278,7 @@ class HTTraQt: public QMainWindow, public Ui_MainWindow, public Translator
         QMenu *langMenu;
         QAction* restAct;
         QActionGroup* langGroup;
-        int dictFormat; // 0 no file, 1 old, 2 new
+        //         int dictFormat; // 0 no file, 1 old, 2 new
         // System tray icon
         bool verbose;
         bool pcShutdown;
@@ -287,7 +292,6 @@ class HTTraQt: public QMainWindow, public Ui_MainWindow, public Translator
         short argc;
         QProcess* process;
         QString cmdOpt;
-        QStringList translateTable;
         // flag de termination
         int termine;
         static int arretbrutal;
@@ -307,15 +311,13 @@ class HTTraQt: public QMainWindow, public Ui_MainWindow, public Translator
         t_InpInfo SInfo;
         t_StatsBuffer StatsBuffer[NStatsBuffer]; // interface to progres tab
 
-        QString currentProject;
+
         QStringList langFiles;
         DirModel dModel;
 
         QMutex mutex;
         QString currentOptionsFile;
         QString defaultOptionsFile;
-        QString currentWorkDir;
-        QString currentAppDir;
         QString helpDir;
         QString langDir;
         QString currentLang;
