@@ -4,16 +4,15 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -21,13 +20,151 @@
 
 #include <QDir>
 
-
 #include "includes/translator.h"
 #include "includes/httraqt.h"
 
 extern HTTraQt* mainWidget;
 
-QString Translator::translate( int id )
+QVector<QString> cTranslator::translateTable;
+
+bool cTranslator::loadTranslation(const QString fname)
+{
+    QFile langFile(fname);
+    short vecSize = (short)(sizeof(engText) / sizeof(char*));
+    translateTable.clear();
+    translateTable.resize(vecSize + 1);
+
+    if (!langFile.open(QIODevice::ReadOnly)) {
+        return false;
+    }
+
+    //     qDebug() << fname;
+
+    QTextStream stream(&langFile);
+    stream.setCodec("UTF-8");
+
+    QString llEng = stream.readLine();
+
+    if (llEng.length() > 0) {
+        llEng.remove("\n");
+    }
+
+    if (llEng == "LANGUAGE_NAME") {
+        translateTable << llEng;
+    } else {
+        MessageBox::exec(this, translate(_FILEERR), "File is not a language file!", QMessageBox::Warning);
+
+        langFile.close();
+        return (false);
+    }
+
+    bool begTranslation = false;
+
+    while (!stream.atEnd()) {
+        llEng = stream.readLine();
+        llEng = convertString(llEng);
+
+        if (llEng.indexOf(QRegExp("t[0-9]{3}=")) == 0) {
+            int num, pos;
+            QString str;
+            pos = llEng.indexOf("=");
+
+            if (pos > 0) {
+                str = llEng.mid(pos + 1);
+                //
+                num = llEng.mid(1, pos - 1).toShort();
+
+                //                     qDebug() << num << str;
+                if (num >= vecSize) {
+                    qDebug() << "size too big";
+                } else {
+                    translateTable[num] = str;
+                }
+            }
+        } else {
+            if (llEng == "Ok") { // translation part beginns with "Ok"
+                begTranslation = true;
+            }
+
+            if (begTranslation == false) {
+                continue;
+            }
+
+            bool found = false;
+            QString llTranslate = stream.readLine();
+
+            if (llTranslate.length() == 0) {
+                continue;
+            }
+
+            llTranslate = convertString(llTranslate);
+
+            for(int i = 0; i < vecSize; i++) { // suche
+                QString tmpEng = engText[i];
+
+                if (tmpEng.indexOf("%HOME%") >= 0) {
+                    tmpEng.replace("%HOME%", QDir::homePath());
+                }
+
+                if ( tmpEng == llEng) {
+                    translateTable[i] = llTranslate;
+                    found = true;
+                    break;
+                }
+            }
+
+            if (found == false) {
+                qDebug() << "no translation found" << llEng;
+            }
+
+        }
+    }
+
+    langFile.close();
+
+    return (true);
+}
+
+
+QString cTranslator::convertString(const QString &s)
+{
+    QString res = s;
+
+    if (res.length() > 0) {
+        res.replace( "\\r\\n", "\n");
+        res.replace( "\\n", "\n");
+        res.replace( "\\t", "\t");
+        res.replace( "\\\\", "/");
+        res.replace( "&amp;", "&");
+        res.replace( "&gt;", ">");
+        res.replace( "&lt;", "<");
+    }
+
+    if (res.length() == 0) {
+        return res;
+    }
+
+    if (res.indexOf("winhttrack") >= 0) {
+        res.replace("winhttrack", "httraqt");
+    }
+
+    if (res.indexOf("C:/") >= 0) {
+        res.replace("C:/", "%HOME%/");
+    }
+
+    if (res.indexOf("c:/") >= 0) {
+        res.replace("c:/", "%HOME%/");
+    }
+
+    if (res.indexOf("%HOME%") >= 0) {
+        res.replace("%HOME%", QDir::homePath());
+    }
+
+    return res;
+}
+
+
+QString cTranslator::translate( int id )
 {
     QString m;
 
@@ -35,27 +172,19 @@ QString Translator::translate( int id )
         return "";
     }
 
-    if (id >= 0 && id < (sizeof(engText) / sizeof(char*))) {
-        m = QString(engText[id]);
+    if (translateTable.size() == 0) {
+        return QString(engText[id]);
+    }
 
-        if (id == 383 || id == 401) {
-            m.replace("%HOME%", QString(QDir::homePath() + "/"));
+    if ((id >= 0) && (id < (int)(sizeof(engText) / sizeof(char*)))) {
+        if(translateTable[id].length() == 0) {
+            m = QString(engText[id]);
+        } else {
+            m = translateTable[id];
         }
-    }
 
-    if (mainWidget->translateTable.size() == 0) {
-        return m;
-    }
-
-    for (QStringList::Iterator iter = mainWidget->translateTable.begin(); iter != mainWidget->translateTable.end(); ++iter) {
-        if (m == (*iter)) {
-            iter++;
-
-            if (m.simplified().length() >= 1) { // if nothing
-                m = (*iter);
-            }
-
-            break;
+        if (m.indexOf("%HOME%") >= 0) {
+            m.replace("%HOME%", QDir::homePath());
         }
     }
 
@@ -63,11 +192,11 @@ QString Translator::translate( int id )
 }
 
 
-QString Translator::engText[] = {
+QString cTranslator::engText[] = {
     "HTTraQt",   // 0
     "N# connections", // 1
     "Select font size", // 2
-    "TimeOut(s)", // 3
+    "TimeOut", // 3
     "Retries", // 4
     "Maximum transfer rate", // 5
     "Minimum transfer rate", // 6
@@ -104,7 +233,7 @@ QString Translator::engText[] = {
     "Activate Debugging Mode (httraqt.log)", // 37
     "Maximum mirroring depth from root address", // 38
     "Maximum mirroring depth for external/forbidden addresses (0, that is, none, is the default)", // 39
-    "Max size of any HTML file (B)", // 40
+    "Max size of any HTML file", // 40
     "Max size of any non-HTML file", // 41
     "Size limit", // 42
     "Pause after downloading..", // 43
@@ -453,7 +582,7 @@ QString Translator::engText[] = {
     "%h\tHost name (ex: www.someweb.com)\n%M\tMD5 URL (128 bits, 32 ascii bytes)\n"
     "%Q\tMD5 query string (128 bits, 32 ascii bytes)\n%q\tMD5 small query string (16 bits, 4 ascii bytes)\n"
     "\n%s?\tShort name (ex: %sN)", // 382
-    "Example:\t%h%p/%n%q.%t\n->\t%HOME%/mirror/www.someweb.com/someimages/image.gif", // 383
+    "Example:\t%h%p/%n%q.%t\n->\t\t%HOME%/mirror/www.someweb.com/someimages/image.gif", // 383
     "Proxy settings", // 384
     "Authentication (only if needed)", // 385
     "Enter proxy address here", // 386
@@ -488,7 +617,7 @@ QString Translator::engText[] = {
     "Please set temporary browser proxy settings to the following values (Copy/Paste Proxy Address and Port).\n"
     "Then click on the Form SUBMIT button in your browser page, or click on the specific link you want to capture.", // 415
     "This will send the desired link from your browser to HTTraQt.", // 416
-    "Abort", // 417
+    "ABORT", // 417
     "Copy/Paste the temporary proxy parameters here", // 418
     "Unable to find Help files!", // 419
     "Unable to save parameters!", // 420
@@ -529,7 +658,7 @@ QString Translator::engText[] = {
     "How You can thank a developer:", // 454
     "Share the link to this program or to this project", // 455
     "Report to developer about bugs or mistakes in the program", // 456
-    "Make a donation, click:", // 457
+    "Donate", // 457
     "\n(Please notify us of any bug or problem)\n\nDevelopment:\n"
     "Interface (Windows): Xavier Roche\nInterface (Qt4/Qt5 based): Eduard Kalinowski\nSpider: Xavier Roche\n"
     "JavaParserClasses: Yann Philippot\n\n(C)1998-2003 Xavier Roche and other contributors\n"
@@ -568,6 +697,8 @@ QString Translator::engText[] = {
     "Units", // 490
     "Open", // 491
     "PC off when finished", // 492
+    "Shutdown counter (minutes)", // 493
+    "Make or correct translation", // 494
     ""
 };
 
