@@ -4,16 +4,15 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -32,7 +31,6 @@ int OptionsDialog::headers[OPTION_SITES] = {_LINKS, _BUILD, _SCANRULEZ, _LIMITS,
                                             _SPIDER, _BROWSERID, _LOGINDEX
                                            };
 
-
 OptionsDialog::OptionsDialog(QWidget* parent, Qt::WindowFlags fl)
     : QDialog(parent, fl)
 {
@@ -42,15 +40,12 @@ OptionsDialog::OptionsDialog(QWidget* parent, Qt::WindowFlags fl)
 
     _tabTextInfos.clear();
 
-    QToolButton* b[] = {buttonLinks, buttonBuild, buttonRulez, buttonLimits, buttonProxy,
-                        buttonExperts, buttonMime, buttonFlow, buttonSpider, buttonBrowser, buttonLog
-                       };
-    memcpy(buttons, b, OPTION_SITES * sizeof(QToolButton*));
-
     for (int i = 0; i < OPTION_SITES; i++) {
-        buttons[i]->setText(translate(headers[i]));
+        tabBar->insertTab (i, translate(headers[i]));
     }
 
+    connect(tabBar, SIGNAL(currentChanged(int)), this, SLOT(switchPages(int)));
+
     pBuild = new optionsBuild(this);
     gridWidget->addWidget((QWidget*)pBuild);
 
@@ -84,27 +79,21 @@ OptionsDialog::OptionsDialog(QWidget* parent, Qt::WindowFlags fl)
     pMime = new optionsMime(this);
     gridWidget->addWidget((QWidget*)pMime);
 
-    initOptions();
+    initOptionsDialog();
 
     setFontForWidgets();
 
     QSettings s(QSettings::UserScope, "KarboSoft", "HTTraQt");
     QPoint pos = s.value("posSettings", QPoint(200, 200)).toPoint();
-    QSize size = s.value("sizeSettings", QSize(830, 480)).toSize();
+    QSize size = s.value("sizeSettings", QSize(700, 550)).toSize();
     resize(size);
     move(pos);
 
-    //      connect(gridWidget, SIGNAL(resizeEvent()), this, SLOT(onOk()));
-
     connect(buttonOk, SIGNAL(clicked()), this, SLOT(onOk()));
     connect(buttonCancel, SIGNAL(clicked()), this, SLOT(reject()));
     connect(pushDefault, SIGNAL(clicked()), this, SLOT(onSaveDefOptions()));
     connect(buttonHelp, SIGNAL(clicked()), this, SLOT(onHelp()));
 
-    for (int i = 0; i < OPTION_SITES; i++) {
-        connect(buttons[i], SIGNAL(clicked(bool)), this, SLOT(switchPages()));
-    }
-
     QWidget* p[] = {pLinks, pBuild, pRulez, pLimits, pProxy, pExperts, pMime, pFlow, pSpider, pBrowser, pLog};
     memcpy(pages, p, OPTION_SITES * sizeof(QWidget*));
 
@@ -116,7 +105,7 @@ OptionsDialog::OptionsDialog(QWidget* parent, Qt::WindowFlags fl)
 
     setToGUI();
 
-    buttons[0]->click();
+    emit switchPages(0);
 }
 
 
@@ -141,58 +130,6 @@ OptionsDialog::~OptionsDialog()
 }
 
 
-void OptionsDialog::resizeEvent(QResizeEvent* se)
-{
-    // QSize s = gridWidget->sizeHint();
-
-    for (int i = 0; i < OPTION_SITES; i++) {
-        pages[i]->adjustSize();
-    }
-
-    QVector<trWidgets>::iterator ivec;
-
-    for (ivec = _tabTextInfos.begin(); ivec != _tabTextInfos.end(); ++ivec) {
-        switch ((*ivec).wtype) {
-            case LABEL: {
-                if((*ivec).gui_ID != -1) {
-                    QString t = autoWrap(translate((*ivec).gui_ID), ((QLabel*)(*ivec).wg)->width() / 10.0); // autowrap
-                    //                     ((QLabel*)(*ivec).wg)->update();
-                    //                     qDebug() << "LABEL" << ((QLabel*)(*ivec).wg)->width();
-                    ((QLabel*)(*ivec).wg)->setText(t);
-                }
-
-                break;
-            }
-
-            case CHECKBOX: {
-                if((*ivec).gui_ID != -1) {
-                    QString t = autoWrap(translate((*ivec).gui_ID), ((QCheckBox*)(*ivec).wg)->width() / 10.0); // autowrap
-                    //                     ((QCheckBox*)(*ivec).wg)->update();
-                    //                     qDebug() << "CHECKBOX" << ((QCheckBox*)(*ivec).wg)->width();
-                    ((QCheckBox*)(*ivec).wg)->setText(t);
-                }
-
-                break;
-            }
-
-            case RADIO: {
-                if((*ivec).gui_ID != -1) {
-                    QString t = autoWrap(translate((*ivec).gui_ID), ((QRadioButton*)(*ivec).wg)->width() / 10.0); // autowrap
-                    //                     ((QRadioButton*)(*ivec).wg)->update();
-                    //                     qDebug() << "RADIO" << ((QRadioButton*)(*ivec).wg)->width();
-                    ((QRadioButton*)(*ivec).wg)->setText(t);
-                }
-
-                break;
-            }
-
-        }
-    }
-
-    QDialog::resizeEvent(se);
-}
-
-
 void OptionsDialog::setFontForWidgets(void)
 {
     QFont f = parent->sysFont;
@@ -210,26 +147,18 @@ void OptionsDialog::setFontForWidgets(void)
     pLog->setFont(f);
     pSpider->setFont(f);
     pMime->setFont(f);
-
-    QString sSheet = QString().sprintf("font-size: %dpt", parent->fontSize + 4);
-
-    labelMain->setStyleSheet(sSheet);
 }
 
 
-void OptionsDialog::initOptions()
+void OptionsDialog::initOptionsDialog()
 {
-    for (QMap<QString, OptStruct>::const_iterator iopt = parent->prOptions.constBegin(); iopt != parent->prOptions.constEnd(); ++iopt) {
-        QString k = iopt.key();
-        trWidgets* w = findId(k);
-
-        if (w != NULL) {
-            (*w).value = (*iopt).value;
-        }
+    QVector<trWidgets>::iterator ivec;
 
+    for (ivec = _tabTextInfos.begin(); ivec != _tabTextInfos.end(); ++ivec) {
+        (*ivec).value = prOptions[ (*ivec).idString ].value;
 #ifdef MY_DEBUG
 
-        if (w == NULL) {
+        if ((*ivec).opttype != prOptions[ (*ivec).idString ].type) {
             qDebug() << "set to gui" << iopt.key() << "not found in gui!";
         }
 
@@ -238,72 +167,50 @@ void OptionsDialog::initOptions()
 }
 
 
-trWidgets *OptionsDialog::findId(const QString &k)
-{
-    QVector<trWidgets>::iterator ivec;
-
-    for (ivec = _tabTextInfos.begin(); ivec != _tabTextInfos.end(); ++ivec) {
-        if ((*ivec).idString == k) {
-            return ivec;
-        }
-    }
-
-    return NULL;
-}
-
-
 void OptionsDialog::getFromGUI()
 {
-    for (QMap<QString, OptStruct>::iterator iopt = parent->prOptions.begin(); iopt != parent->prOptions.end(); ++iopt) {
-        QString k = iopt.key();
-        trWidgets* w = findId(k);
+    for (QVector<trWidgets>::iterator ivec = _tabTextInfos.begin(); ivec != _tabTextInfos.end(); ++ivec) {
+        short optType = ((*ivec).opttype & 0x0f);
 
-        if (w == NULL) {
-#ifdef MY_DEBUG
-            qDebug() << "get from gui" << iopt.key() << "not found in gui!";
-#endif
-            continue;
-        }
-
-        switch ((*w).wtype) {
+        switch ((*ivec).wtype) {
             case CHECKBOX:
-                (*w).value = ((QCheckBox*)(*w).wg)->isChecked() ? 1 : 0;
+                (*ivec).value = ((QCheckBox*)(*ivec).wg)->isChecked() ? 1 : 0;
                 break;
 
             case EDITLINE: {
-                if ((*w).opttype == INTEGER) {
-                    if (((QLineEdit*)(*w).wg)->text().length() > 0) {
-                        (*w).value = ((QLineEdit*)(*w).wg)->text().toInt();
+                if ( optType == INTEGER) {
+                    if (((QLineEdit*)(*ivec).wg)->text().length() > 0) {
+                        (*ivec).value = ((QLineEdit*)(*ivec).wg)->text().toInt();
                     }
                 } else {
-                    (*w).value = -1;
+                    (*ivec).value = -1;
                 }
 
-                if ((*w).opttype == FLOAT) {
-                    if (((QLineEdit*)(*w).wg)->text().length() > 0) {
-                        (*w).value = ((QLineEdit*)(*w).wg)->text().toFloat();
+                if (optType == FLOAT) {
+                    if (((QLineEdit*)(*ivec).wg)->text().length() > 0) {
+                        (*ivec).value = ((QLineEdit*)(*ivec).wg)->text().toFloat();
                     } else {
-                        (*w).value = -1;
+                        (*ivec).value = -1;
                     }
                 }
 
-                if ((*w).opttype == TEXT) {
-                    (*w).value = ((QLineEdit*)(*w).wg)->text();
+                if (optType == TEXT) {
+                    (*ivec).value = ((QLineEdit*)(*ivec).wg)->text();
                 }
 
                 break;
             }
 
             case LABEL: {
-                if ((*w).opttype == TEXT) {
-                    (*w).value = ((QLabel*)(*w).wg)->text();
+                if (optType == TEXT) {
+                    (*ivec).value = ((QLabel*)(*ivec).wg)->text();
                 }
 
                 break;
             }
 
             case TEXTEDIT: { // this one only for rulez->scanList
-                (*w).value = ((QTextEdit*)(*w).wg)->toPlainText();
+                (*ivec).value = ((QTextEdit*)(*ivec).wg)->toPlainText();
                 break;
             }
 
@@ -311,47 +218,47 @@ void OptionsDialog::getFromGUI()
                 break;
 
             case GROUPBOX: {
-                if ((*w).opttype == BOOLEAN) {
-                    (*w).value = ((QGroupBox*)(*w).wg)->isChecked() ? 1 : 0;
+                if (optType == BOOLEAN) {
+                    (*ivec).value = ((QGroupBox*)(*ivec).wg)->isChecked() ? 1 : 0;
                 }
 
                 break;
             }
 
             case COMBOBOX: {
-                if ((*w).opttype == TEXT) {
-                    (*w).value = ((QComboBox*)(*w).wg)->currentText();
+                if (optType == TEXT) {
+                    (*ivec).value = ((QComboBox*)(*ivec).wg)->currentText();
                 }
 
-                if ((*w).opttype == INTEGER || (*w).opttype == FLOAT) {
+                if (optType == INTEGER || optType == FLOAT) {
                     bool ok;
-                    QString ct = ((QComboBox*)(*w).wg)->currentText();
+                    QString ct = ((QComboBox*)(*ivec).wg)->currentText();
 
                     if (ct == "" || ct == "-") {
-                        //                                 qDebug() << "get options combo" << (*w).idString << (*w).value;
-                        if ((*w).opttype == INTEGER ) {
-                            (*w).value = -1;
+                        //                                 qDebug() << "get options combo" << (*ivec).idString << (*ivec).value;
+                        if (optType == INTEGER ) {
+                            (*ivec).value = -1;
                         }
 
-                        if ((*w).opttype == FLOAT ) {
-                            (*w).value = -1.0;
+                        if (optType == FLOAT ) {
+                            (*ivec).value = -1.0;
                         }
                     } else {
-                        if ((*w).opttype == INTEGER ) {
+                        if (optType == INTEGER ) {
                             int  num = ct.toInt(&ok);
 
                             if (ok == true) {
-                                (*w).value = num;
+                                (*ivec).value = num;
                             } else {
-                                (*w).value = ((QComboBox*)(*w).wg)->currentIndex();
+                                (*ivec).value = ((QComboBox*)(*ivec).wg)->currentIndex();
                             }
                         } else {
                             float  num = ct.toFloat(&ok);
 
                             if (ok == true) {
-                                (*w).value = num;
+                                (*ivec).value = num;
                             } else {
-                                (*w).value = ((QComboBox*)(*w).wg)->currentIndex();
+                                (*ivec).value = ((QComboBox*)(*ivec).wg)->currentIndex();
                             }
                         }
                     }
@@ -361,67 +268,23 @@ void OptionsDialog::getFromGUI()
             }
         }
 
-        (*iopt).value = (*w).value;
+        prOptions[ (*ivec).idString ].value = (*ivec).value;
     }
 }
 
 
-QString OptionsDialog::autoWrap(const QString &t, const int max)
-{
-    QString res;
-    QString tmp = t;
-
-    //     if (max == NOWRAP ) {
-    //         return tmp;
-    //     }
-
-    tmp.replace("\n", " ");
-    int pos;
-
-    if (t.length() == 0) {
-        return "";
-    }
-
-    if (t.length() < max) {
-        return tmp;
-    }
-
-    pos = tmp.lastIndexOf(" ", max);
-
-    if (pos <= 0 ) {
-        return tmp;
-    }
-
-    while (pos > 0) {
-        //         if (pos > 0){
-        res += tmp.left(pos) + "\n";
-        tmp = tmp.mid(pos + 1);
-        //         }
-        //         res += "\n";
-        pos = tmp.lastIndexOf(" ", max);
-
-        if (pos < 0) {
-            res += tmp;
-            break;
-        }
-    };
-
-    return res;
-}
-
-
 void OptionsDialog::setToGUI()
 {
-    QVector<trWidgets>::iterator ivec;
+    for (QVector<trWidgets>::iterator ivec = _tabTextInfos.begin(); ivec != _tabTextInfos.end(); ++ivec) {
+        short optTypeLo = (*ivec).opttype & 0x0f;
+        bool nonZero = (((*ivec).opttype & 0x80) != 0);
 
-    for (ivec = _tabTextInfos.begin(); ivec != _tabTextInfos.end(); ++ivec) {
         switch ((*ivec).wtype) {
             case LABEL: {
                 if((*ivec).gui_ID != -1) {
-                    QString t = autoWrap(translate((*ivec).gui_ID), ((QLabel*)(*ivec).wg)->width() / 10); // autowrap
-                    ((QLabel*)(*ivec).wg)->setText(t);
+                    ((QLabel*)(*ivec).wg)->setText(translate((*ivec).gui_ID).replace("\n", " "));
                 } else {
-                    ((QLabel*)(*ivec).wg)->setText(translate((*ivec).value.toInt()));
+                    ((QLabel*)(*ivec).wg)->setText(translate((*ivec).value.toInt()).replace("\n", " "));
                 }
 
                 break;
@@ -442,11 +305,10 @@ void OptionsDialog::setToGUI()
 
             case CHECKBOX: {
                 if((*ivec).gui_ID != -1) {
-                    QString t = autoWrap(translate((*ivec).gui_ID), ((QCheckBox*)(*ivec).wg)->width() / 10); // autowrap
-                    ((QCheckBox*)(*ivec).wg)->setText(t);
+                    ((QCheckBox*)(*ivec).wg)->setText(translate((*ivec).gui_ID).replace("\n", " "));
                 }
 
-                if ((*ivec).opttype != TEXT) {
+                if (optTypeLo != TEXT) {
                     if ((*ivec).value.toInt() == 1) {
                         ((QCheckBox*)(*ivec).wg)->setCheckState(Qt::Checked);
                     } else {
@@ -463,7 +325,7 @@ void OptionsDialog::setToGUI()
                     ((QGroupBox*)(*ivec).wg)->setTitle(translate((*ivec).gui_ID));
                 }
 
-                if ((*ivec).opttype == BOOLEAN) {
+                if (optTypeLo == BOOLEAN) {
                     if ((*ivec).value.toInt() == 1) {
                         ((QGroupBox*)(*ivec).wg)->setChecked(true);
                     } else {
@@ -475,7 +337,7 @@ void OptionsDialog::setToGUI()
             }
 
             case COMBOBOX: {
-                if ((*ivec).opttype == TEXT) {
+                if (optTypeLo == TEXT) {
                     int index = ((QComboBox*)(*ivec).wg)->findText((*ivec).value.toString());
 
                     if (index >= 0) {
@@ -483,157 +345,164 @@ void OptionsDialog::setToGUI()
                     } else {
                         QString t = (*ivec).value.toString();
                         ((QComboBox*)(*ivec).wg)->addItem(t);
-                        ((QComboBox*)(*ivec).wg)->model()->sort(0);
                         int tInd = ((QComboBox*)(*ivec).wg)->findText(t);
                         ((QComboBox*)(*ivec).wg)->setCurrentIndex(tInd);
                     }
-                } else {
-                    int num;
 
-                    if (((QComboBox*)(*ivec).wg)->findText("") == -1) {
-                        num = (*ivec).value.toInt();
-                        ((QComboBox*)(*ivec).wg)->setCurrentIndex(num);
-                        break;
-                    }
-
-                    if ((*ivec).opttype == INTEGER) {
-                        int pos;
-
-                        num = (*ivec).value.toInt();
-
-                        if ( num == -1) {
-                            pos = ((QComboBox*)(*ivec).wg)->findText("");
-                            ((QComboBox*)(*ivec).wg)->setCurrentIndex(pos);
-                        } else {
-                            pos = ((QComboBox*)(*ivec).wg)->findText(QString::number(num));
-
-                            if (pos >= 0) {
-                                ((QComboBox*)(*ivec).wg)->setCurrentIndex(pos);
-                            } else {
-                                QString t = QString::number((*ivec).value.toInt());
-                                ((QComboBox*)(*ivec).wg)->addItem(t);
-                                ((QComboBox*)(*ivec).wg)->model()->sort(0);
-                                int tInd = ((QComboBox*)(*ivec).wg)->findText(t);
-                                ((QComboBox*)(*ivec).wg)->setCurrentIndex(tInd);
-                            }
-                        }
-
-                        break;
-                    }
-
-                    if ((*ivec).opttype == FLOAT) {
-                        int pos;
-
-                        // qDebug() << "set to gui" << (*ivec).idString << (*ivec).value;
-                        if ((*ivec).value.toFloat() == -1.0) {
-                            pos = ((QComboBox*)(*ivec).wg)->findText("");
-                            ((QComboBox*)(*ivec).wg)->setCurrentIndex(pos);
-                        } else {
-                            pos = ((QComboBox*)(*ivec).wg)->findText(QString::number((*ivec).value.toFloat()));
-
-                            if (pos >= 0) {
-                                ((QComboBox*)(*ivec).wg)->setCurrentIndex(pos);
-                            } else {
-                                QString t = QString::number((*ivec).value.toFloat());
-                                ((QComboBox*)(*ivec).wg)->addItem(t);
-                                ((QComboBox*)(*ivec).wg)->model()->sort(0);
-                                int tInd = ((QComboBox*)(*ivec).wg)->findText(t);
-                                ((QComboBox*)(*ivec).wg)->setCurrentIndex(tInd);
-                            }
-                        }
-
-                        break;
-                    }
+                    break;
                 }
 
-                break;
+                int num;
+
+                if (((QComboBox*)(*ivec).wg)->findText("") == -1) {
+                    num = (*ivec).value.toInt();
+                    ((QComboBox*)(*ivec).wg)->setCurrentIndex(num);
+                    break;
+                }
+
+                if (optTypeLo == INTEGER) {
+                    int pos;
+
+                    num = (*ivec).value.toInt();
+
+                    if ( num == -1 || nonZero) {
+                        pos = ((QComboBox*)(*ivec).wg)->findText("");
+                        ((QComboBox*)(*ivec).wg)->setCurrentIndex(pos);
+                    } else {
+                        QString st = QString::number(num);
+                        insertInCombo(*(QComboBox*)(*ivec).wg, st);
+                    }
+
+                    break;
+                }
+
+                if (optTypeLo == FLOAT) {
+                    int pos;
+
+                    // qDebug() << "set to gui" << (*ivec).idString << (*ivec).value;
+                    if ((*ivec).value.toFloat() == -1.0 || nonZero) {
+                        pos = ((QComboBox*)(*ivec).wg)->findText("");
+                        ((QComboBox*)(*ivec).wg)->setCurrentIndex(pos);
+                    } else {
+                        QString st = QString::number((*ivec).value.toFloat());
+                        insertInCombo(*(QComboBox*)(*ivec).wg, st);
+                    }
+
+                    break;
+                }
             }
 
             case RADIO: {
                 if((*ivec).gui_ID != -1) {
-                    QString t = autoWrap(translate((*ivec).gui_ID), ((QRadioButton*)(*ivec).wg)->width() / 10); // autowrap
-                    ((QRadioButton*)(*ivec).wg)->setText(t);
+                    ((QRadioButton*)(*ivec).wg)->setText(translate((*ivec).gui_ID).replace("\n", " "));
                 }
 
                 break;
             }
 
             case EDITLINE: {// no translate for edit widget
-                if ((*ivec).opttype == INTEGER) {
-                    if ((*ivec).value.toInt() == -1) {
+                if (optTypeLo == INTEGER) {
+                    if ((*ivec).value.toInt() == -1 || nonZero) {
                         ((QLineEdit*)(*ivec).wg)->setText("");
                     } else {
                         ((QLineEdit*)(*ivec).wg)->setText(QString::number((*ivec).value.toInt()));
                     }
+
+                    break;
                 }
 
-                if ((*ivec).opttype == FLOAT) {
-                    if ((*ivec).value.toFloat() == -1.0) {
+                if (optTypeLo == FLOAT) {
+                    if ((*ivec).value.toFloat() == -1.0 || nonZero) {
                         ((QLineEdit*)(*ivec).wg)->setText("");
                     } else {
                         ((QLineEdit*)(*ivec).wg)->setText(QString::number((*ivec).value.toFloat()));
                     }
+
+                    break;
                 }
 
-                if ((*ivec).opttype == TEXT) {
+                if (optTypeLo == TEXT) {
                     ((QLineEdit*)(*ivec).wg)->setText((*ivec).value.toString());
+                    break;
                 }
-
-                break;
             }
         }
     }
 }
 
 
+void OptionsDialog::insertInCombo( QComboBox &box, const QString &s)
+{
+    float tmp;
+    bool conv;
+
+    tmp = s.toFloat(&conv);
+
+    if (conv == false) {
+        qDebug() << "convert error" << s << "to float";
+        return;
+    }
+
+    if (box.count() < 2) {
+        return;
+    }
+
+    for(int ib = 1; ib != box.count() - 1; ++ib) { // the first is "space" or -1
+        float a, b;
+        a = box.itemText(ib).toFloat();
+
+        if (tmp < a) {
+            continue;
+        }
+
+        b = box.itemText(ib + 1).toFloat();
+
+        if (tmp == a) {
+            box.setCurrentIndex(ib);
+            return; // exists
+        }
+
+        if (tmp == b) {
+            box.setCurrentIndex(ib + 1);
+            return; // exists
+        }
+
+        if (tmp < b) {
+            box.insertItem(ib + 1, s);
+            return;
+        }
+    }
+}
+
+
 void OptionsDialog::onHelp()
 {
     QDesktopServices::openUrl(QUrl::fromLocalFile(qPrintable( parent->helpDir + "/step9.html")));
 }
 
 
-void OptionsDialog::switchPages()
+void OptionsDialog::switchPages(int n)
 {
-    int n = -1;
     QToolButton* s = (QToolButton*)sender();
 
-    for (int i = 0; i < OPTION_SITES; i++) {
-        if (buttons[i] == s) {
-            n = i;
-            break;
-        }
-    }
-
     if (n == -1) {
         return;
     }
 
-    for (int i = 0; i < OPTION_SITES; i++) {
-        disconnect(buttons[i], SIGNAL(clicked(bool)), this, SLOT(switchPages()));
-    }
-
     for (int i = 0; i < OPTION_SITES; i++) {
         if (i == n) {
-            labelMain->setText(translate(headers[i]));
             pages[i]->show();
-            //             pages[i]->adjustSize();
-            buttons[i]->setChecked(true);
             continue;
         }
 
         pages[i]->hide();
-        buttons[i]->setChecked(false);
-    }
-
-    for (int i = 0; i < OPTION_SITES; i++) {
-        connect(buttons[i], SIGNAL(clicked(bool)), this, SLOT(switchPages()));
     }
 }
 
 
 void OptionsDialog::onResetDefOptions()
 {
-    parent->resetDefaultOptions();
+    parent->initOptions();
     parent->writeSettings(true);
 }
 
