@@ -1,19 +1,18 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012 by Eduard Kalinowski                                 *
+ * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -42,6 +41,8 @@ struct trWidgets {
 #define OPTIONSDIALOG_H
 
 #include "../../main/includes/httraqt.h"
+#include "../../main/includes/options.h"
+
 #include "ui_OptionsDialog.h"
 // #include "ui_optionsBuild.h"
 
@@ -70,12 +71,6 @@ struct trWidgets {
 #define EDITLINE 7
 #define TEXTEDIT 8
 
-#define NOTYPE   0
-#define BOOLEAN  1
-#define INTEGER  2
-#define TEXT     3
-#define FLOAT    4
-
 
 class optionsBuild;
 class optionsBrowser;
@@ -90,7 +85,7 @@ class optionsSpider;
 class optionsMime;
 
 
-class OptionsDialog: public QDialog, public Ui_OptionsDialog, public Translator
+class OptionsDialog: public QDialog, public Ui::OptionsDialog, public cTranslator, public cOptions
 {
         Q_OBJECT
     public:
@@ -100,20 +95,18 @@ class OptionsDialog: public QDialog, public Ui_OptionsDialog, public Translator
         void onSetDefOptions();
         void setToGUI();
         void getFromGUI();
-        void initOptions();
+        void initOptionsDialog();
         void setFontForWidgets(void);
-        QString autoWrap(const QString &t, const int max);
 
     private slots:
         void onHelp();
         void onOk();
         void onSaveDefOptions();
         void onResetDefOptions();
-        void switchPages();
+        void switchPages(int n);
 
     private:
-        void resizeEvent(QResizeEvent* se);
-        trWidgets* findId(const QString& k);
+        void insertInCombo( QComboBox &b, const QString &s);
 
     private:
         optionsBuild*   pBuild;
@@ -129,7 +122,6 @@ class OptionsDialog: public QDialog, public Ui_OptionsDialog, public Translator
         optionsMime*    pMime;
 
         // max OPTION_SITES
-        QToolButton*    buttons[OPTION_SITES];
         QWidget*        pages[OPTION_SITES];
         static int      headers[OPTION_SITES];
 
