@@ -4,16 +4,15 @@
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
- * HTTraQt is free software; you can redistribute it and/or                *
- * modify it under the terms of the GNU Lesser General Public              *
- * License as published by the Free Software Foundation; either            *
- * version 3 of the License, or (at your option) any later version.        *
+ * HTTraQt is free software; may be distributed and/or modified under the  *
+ * terms of the GNU General Public License version 3 as published by the   *
+ * Free Software Foundation and appearing in the file LICENSE_GPLv3        *
+ * included in the packaging of this file.                                 *
  *                                                                         *
- * HTTraQt is distributed in the hope that it will be useful, but          *
- * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
- *                                                                         *
- * See the GNU Lesser General Public License for more details.             *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
+ * GNU General Public License for more details.                            *
  *                                                                         *
  * You should have received a copy of the GNU Lesser General Public        *
  * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
@@ -33,26 +32,26 @@ optionsLimits::optionsLimits(QWidget* parent, Qt::WindowFlags fl)
     QStringList maxTime;
     maxTime << "" << "120" << "900" << "1800" << "3600" << "7200";
     limitsForm::comboMaxTime->insertItems(0, maxTime);    // max time overall
-    limitsForm::comboMaxTime->setDuplicatesEnabled(true);
+    limitsForm::comboMaxTime->setDuplicatesEnabled(false);
 
     connect (limitsForm::comboMaxTime->lineEdit(), SIGNAL(editingFinished()), this, SLOT(editingFinished()));
 
     QStringList connSec;
     connSec << "" << "1" << "2" << "4" << "8" << "16" << "32" << "64" << "128";
     limitsForm::comboMaxConn->insertItems(0, connSec);    // max connections/sec
-    limitsForm::comboMaxConn->setDuplicatesEnabled(true);
+    limitsForm::comboMaxConn->setDuplicatesEnabled(false);
 
     connect (limitsForm::comboMaxConn->lineEdit(), SIGNAL(editingFinished()), this, SLOT(editingFinished()));
 
     limitsForm::comboMaxDep->insertItems(0, connSec); // max depth
-    limitsForm::comboMaxDep->setDuplicatesEnabled(true);
+    limitsForm::comboMaxDep->setDuplicatesEnabled(false);
 
     connect (limitsForm::comboMaxDep->lineEdit(), SIGNAL(editingFinished()), this, SLOT(editingFinished()));
 
     QStringList extD;
     extD << "" << "0" << "1" << "2" << "4" << "8" << "16" << "32" << "64" << "128";
     limitsForm::comboMaxExtDep->insertItems(0, extD); // max links
-    limitsForm::comboMaxExtDep->setDuplicatesEnabled(true);
+    limitsForm::comboMaxExtDep->setDuplicatesEnabled(false);
     connect (limitsForm::comboMaxExtDep->lineEdit(), SIGNAL(editingFinished()), this, SLOT(editingFinished()));
 
     QStringList maxLinks;
@@ -65,7 +64,7 @@ optionsLimits::optionsLimits(QWidget* parent, Qt::WindowFlags fl)
     QStringList maxTransferRate;
     maxTransferRate << "" << "0.0001" << "0.001" << "0.01" << "0.1" << "0.5" << "1" << "5" << "20" << "50" << "75" << "100" << "250";
     limitsForm::comboMaxTransf->insertItems(0, maxTransferRate);   // max transfer rate
-    limitsForm::comboMaxTransf->setDuplicatesEnabled(true);
+    limitsForm::comboMaxTransf->setDuplicatesEnabled(false);
 
     connect (limitsForm::comboMaxTransf->lineEdit(), SIGNAL(editingFinished()), this, SLOT(editingFinished()));
 
