@@ -1,8 +1,8 @@
 #ifndef HTTVERSION_H
 #define HTTVERSION_H
 
-#define HTTQTVERSION  "1.3.0"
-#define PROGRAM_DATE  "29 Jan 2014"
+#define HTTQTVERSION  "1.4.4"
+#define PROGRAM_DATE  "17 Jul 2014"
 
 #define USE_QT_VERSION  4
 
